Setup
=====

To install, run:

.. code-block:: bash

    pip install ytmusicapi


Further setup is only needed if you want to access account data using authenticated requests.

The simplest way of authentication is to use :doc:`oauth`.

However, these OAuth credentials do not work for uploads. If you need to upload music,
instead follow the instructions at :doc:`browser`.



.. toctree::
   :caption: Table of Contents

   oauth
   browser